aboutsummaryrefslogtreecommitdiff
path: root/gdb/gdbarch.h
diff options
context:
space:
mode:
authorAndrew Cagney <cagney@redhat.com>2003-09-09 03:58:18 +0000
committerAndrew Cagney <cagney@redhat.com>2003-09-09 03:58:18 +0000
commit88a82a65e0c920f2b543fb1c9eed02b8554b2db2 (patch)
tree008e298e0866de90a83aa1b7a9b603c788e23a6c /gdb/gdbarch.h
parent3e2c403395e32572a8b6f0ed4cc4f8f73d8040c0 (diff)
downloadgdb-88a82a65e0c920f2b543fb1c9eed02b8554b2db2.zip
gdb-88a82a65e0c920f2b543fb1c9eed02b8554b2db2.tar.gz
gdb-88a82a65e0c920f2b543fb1c9eed02b8554b2db2.tar.bz2
2003-09-08 Andrew Cagney <cagney@redhat.com>
* gdbarch.sh (DEPRECATED_CALL_DUMMY_ADDRESS): Rename CALL_DUMMY_ADDRESS, change to a predicate. * gdbarch.h, gdbarch.c: Re-generate. * blockframe.c (deprecated_pc_in_call_dummy_at_entry_point): Use either DEPRECATED_CALL_DUMMY_ADDRESS or entry_point_address. * infcall.c (call_function_by_hand): Ditto. * sparc-tdep.c (sparc_push_return_address): Ditto. (sparc_gdbarch_init): Set deprecated_call_dummy_address. * xstormy16-tdep.c (xstormy16_push_return_address): Replace CALL_DUMMY_ADDRESS with entry_point_address. * v850-tdep.c (v850_push_return_address): Ditto. * s390-tdep.c (s390_push_return_address): Ditto. * rs6000-tdep.c (ppc_push_return_address): Ditto. * mn10300-tdep.c (mn10300_push_return_address): Ditto. * mcore-tdep.c (mcore_push_return_address): Ditto. * cris-tdep.c (cris_push_return_address): Ditto. * arm-tdep.c (arm_push_return_address): Ditto.
Diffstat (limited to 'gdb/gdbarch.h')
-rw-r--r--gdb/gdbarch.h31
1 files changed, 23 insertions, 8 deletions
diff --git a/gdb/gdbarch.h b/gdb/gdbarch.h
index 1471378..a15044b 100644
--- a/gdb/gdbarch.h
+++ b/gdb/gdbarch.h
@@ -846,14 +846,29 @@ extern void set_gdbarch_call_dummy_location (struct gdbarch *gdbarch, int call_d
#define CALL_DUMMY_LOCATION (gdbarch_call_dummy_location (current_gdbarch))
#endif
-typedef CORE_ADDR (gdbarch_call_dummy_address_ftype) (void);
-extern CORE_ADDR gdbarch_call_dummy_address (struct gdbarch *gdbarch);
-extern void set_gdbarch_call_dummy_address (struct gdbarch *gdbarch, gdbarch_call_dummy_address_ftype *call_dummy_address);
-#if (GDB_MULTI_ARCH > GDB_MULTI_ARCH_PARTIAL) && defined (CALL_DUMMY_ADDRESS)
-#error "Non multi-arch definition of CALL_DUMMY_ADDRESS"
-#endif
-#if !defined (CALL_DUMMY_ADDRESS)
-#define CALL_DUMMY_ADDRESS() (gdbarch_call_dummy_address (current_gdbarch))
+#if defined (DEPRECATED_CALL_DUMMY_ADDRESS)
+/* Legacy for systems yet to multi-arch DEPRECATED_CALL_DUMMY_ADDRESS */
+#if !defined (DEPRECATED_CALL_DUMMY_ADDRESS_P)
+#define DEPRECATED_CALL_DUMMY_ADDRESS_P() (1)
+#endif
+#endif
+
+extern int gdbarch_deprecated_call_dummy_address_p (struct gdbarch *gdbarch);
+#if (GDB_MULTI_ARCH > GDB_MULTI_ARCH_PARTIAL) && defined (DEPRECATED_CALL_DUMMY_ADDRESS_P)
+#error "Non multi-arch definition of DEPRECATED_CALL_DUMMY_ADDRESS"
+#endif
+#if (GDB_MULTI_ARCH > GDB_MULTI_ARCH_PARTIAL) || !defined (DEPRECATED_CALL_DUMMY_ADDRESS_P)
+#define DEPRECATED_CALL_DUMMY_ADDRESS_P() (gdbarch_deprecated_call_dummy_address_p (current_gdbarch))
+#endif
+
+typedef CORE_ADDR (gdbarch_deprecated_call_dummy_address_ftype) (void);
+extern CORE_ADDR gdbarch_deprecated_call_dummy_address (struct gdbarch *gdbarch);
+extern void set_gdbarch_deprecated_call_dummy_address (struct gdbarch *gdbarch, gdbarch_deprecated_call_dummy_address_ftype *deprecated_call_dummy_address);
+#if (GDB_MULTI_ARCH > GDB_MULTI_ARCH_PARTIAL) && defined (DEPRECATED_CALL_DUMMY_ADDRESS)
+#error "Non multi-arch definition of DEPRECATED_CALL_DUMMY_ADDRESS"
+#endif
+#if !defined (DEPRECATED_CALL_DUMMY_ADDRESS)
+#define DEPRECATED_CALL_DUMMY_ADDRESS() (gdbarch_deprecated_call_dummy_address (current_gdbarch))
#endif
/* DEPRECATED_CALL_DUMMY_START_OFFSET can be deleted. */